==> ckeditor_4.4.4+dfsg1.orig.tar.xz: ckeditor-dev-4.4.4/lang/sq.js <==
﻿/**
 * @license Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
 * For licensing, see LICENSE.md or http://ckeditor.com/license
 */

/**
 * @fileOverview
 */

/**#@+
   @type String
   @example
*/

/**
 * Contains the dictionary of language entries.
 * @namespace
 */
CKEDITOR.lang[ 'sq' ] = {
	// ARIA description.
	editor: 'Redaktues i Pasur Teksti',
	editorPanel: 'Rich Text Editor panel', // MISSING

	// Common messages and labels.
	common: {
		// Screenreader titles. Please note that screenreaders are not always capable
		// of reading non-English words. So be careful while translating it.
		editorHelp: 'Shtyp ALT 0 për ndihmë',

		browseServer: 'Shfleto në Server',
		url: 'URL',
		protocol: 'Protokolli',
		upload: 'Ngarko',
		uploadSubmit: 'Dërgo në server',
		image: 'Imazh',
		flash: 'Objekt flash',
		form: 'Formular',
		checkbox: 'Checkbox',
		radio: 'Buton radio',
		textField: 'Fushë tekst',
		textarea: 'Hapësirë tekst',
		hiddenField: 'Fushë e fshehur',
		button: 'Buton',
		select: 'Menu zgjedhjeje',
		imageButton: 'Buton imazhi',
		notSet: '<e pazgjedhur>',
		id: 'Id',
		name: 'Emër',
		langDir: 'Kod gjuhe',
		langDirLtr: 'Nga e majta në të djathtë (LTR)',
		langDirRtl: 'Nga e djathta në të majtë (RTL)',
		langCode: 'Kod gjuhe',
		longDescr: 'Përshkrim i hollësishëm',
		cssClass: 'Klasa stili CSS',
		advisoryTitle: 'Titull',
		cssStyle: 'Stil',
		ok: 'OK',
		cancel: 'Anulo',
		close: 'Mbyll',
		preview: 'Parashiko',
		resize: 'Ripërmaso',
		generalTab: 'Të përgjithshme',
		advancedTab: 'Të përparuara',
		validateNumberFailed: 'Vlera e futur nuk është një numër',
		confirmNewPage: 'Çdo ndryshim që nuk është ruajtur do humbasë. Je i sigurtë që dëshiron të krijosh një faqe të re?',
		confirmCancel: 'Disa opsione kanë ndryshuar. Je i sigurtë që dëshiron ta mbyllësh dritaren?',
		options: 'Opsione',
		target: 'Objektivi',
		targetNew: 'Dritare e re (_blank)',
		targetTop: 'Dritare në plan të parë (_top)',
		targetSelf: 'E njëjta dritare (_self)',
		targetParent: 'Dritarja prind (_parent)',
		langDirLTR: 'Nga e majta në të djathë (LTR)',
		langDirRTL: 'Nga e djathta në të majtë (RTL)',
		styles: 'Stil',
		cssClasses: 'Klasa Stili CSS',
		width: 'Gjerësi',
		height: 'Lartësi',
		align: 'Rreshtim',
		alignLeft: 'Majtas',
		alignRight: 'Djathtas',
		alignCenter: 'Qendër',
		alignJustify: 'Zgjero',
		alignTop: 'Lart',
		alignMiddle: 'Në mes',
		alignBottom: 'Poshtë',
		alignNone: 'None', // MISSING
		invalidValue	: 'Vlerë e pavlefshme',
		invalidHeight: 'Lartësia duhet të jetë një numër',
		invalidWidth: 'Gjerësia duhet të jetë një numër',
		invalidCssLength: 'Vlera e fushës "%1" duhet të jetë një numër pozitiv me apo pa njësi matëse të vlefshme CSS (px, %, in, cm, mm, em, ex, pt ose pc).',
		invalidHtmlLength: 'Vlera e fushës "%1" duhet të jetë një numër pozitiv me apo pa njësi matëse të vlefshme HTML (px ose %)',
		invalidInlineStyle: 'Stili inline duhet të jetë një apo disa vlera të formatit "emër: vlerë", ndarë nga pikëpresje.',
		cssLengthTooltip: 'Fut një numër për vlerën në pixel apo një numër me një njësi të vlefshme CSS (px, %, in, cm, mm, ex, pt, ose pc).',

		// Put the voice-only part of the label in the span.
		unavailable: '%1<span class="cke_accessibility">, i padisponueshëm</span>'
	}
};

==> ckeditor_4.5.7+dfsg.orig.tar.xz: ckeditor-dev-4.5.7/lang/sq.js <==
/**
 * @license Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
 * For licensing, see LICENSE.md or http://ckeditor.com/license
 */

/**
 * @fileOverview
 */

/**#@+
   @type String
   @example
*/

/**
 * Contains the dictionary of language entries.
 * @namespace
 */
CKEDITOR.lang[ 'sq' ] = {
	// ARIA description.
	editor: 'Redaktues i Pasur Teksti',
	editorPanel: 'Paneli i redaktuesit të tekstit të plotë',

	// Common messages and labels.
	common: {
		// Screenreader titles. Please note that screenreaders are not always capable
		// of reading non-English words. So be careful while translating it.
		editorHelp: 'Shtyp ALT 0 për ndihmë',

		browseServer: 'Shfleto në Server',
		url: 'URL',
		protocol: 'Protokolli',
		upload: 'Ngarko',
		uploadSubmit: 'Dërgo në server',
		image: 'Imazh',
		flash: 'Objekt flash',
		form: 'Formular',
		checkbox: 'Checkbox',
		radio: 'Buton radio',
		textField: 'Fushë tekst',
		textarea: 'Hapësirë tekst',
		hiddenField: 'Fushë e fshehur',
		button: 'Buton',
		select: 'Menu zgjedhjeje',
		imageButton: 'Buton imazhi',
		notSet: '<e pazgjedhur>',
		id: 'Id',
		name: 'Emër',
		langDir: 'Kod gjuhe',
		langDirLtr: 'Nga e majta në të djathtë (LTR)',
		langDirRtl: 'Nga e djathta në të majtë (RTL)',
		langCode: 'Kod gjuhe',
		longDescr: 'Përshkrim i hollësishëm',
		cssClass: 'Klasa stili CSS',
		advisoryTitle: 'Titull',
		cssStyle: 'Stil',
		ok: 'OK',
		cancel: 'Anulo',
		close: 'Mbyll',
		preview: 'Parashiko',
		resize: 'Ripërmaso',
		generalTab: 'Të përgjithshme',
		advancedTab: 'Të përparuara',
		validateNumberFailed: 'Vlera e futur nuk është një numër',
		confirmNewPage: 'Çdo ndryshim që nuk është ruajtur do humbasë. Je i sigurtë që dëshiron të krijosh një faqe të re?',
		confirmCancel: 'Disa opsione kanë ndryshuar. Je i sigurtë që dëshiron ta mbyllësh dritaren?',
		options: 'Opsione',
		target: 'Objektivi',
		targetNew: 'Dritare e re (_blank)',
		targetTop: 'Dritare në plan të parë (_top)',
		targetSelf: 'E njëjta dritare (_self)',
		targetParent: 'Dritarja prind (_parent)',
		langDirLTR: 'Nga e majta në të djathë (LTR)',
		langDirRTL: 'Nga e djathta në të majtë (RTL)',
		styles: 'Stil',
		cssClasses: 'Klasa Stili CSS',
		width: 'Gjerësi',
		height: 'Lartësi',
		align: 'Rreshtim',
		alignLeft: 'Majtas',
		alignRight: 'Djathtas',
		alignCenter: 'Qendër',
		alignJustify: 'Zgjero',
		alignTop: 'Lart',
		alignMiddle: 'Në mes',
		alignBottom: 'Poshtë',
		alignNone: 'Asnjë',
		invalidValue	: 'Vlerë e pavlefshme',
		invalidHeight: 'Lartësia duhet të jetë një numër',
		invalidWidth: 'Gjerësia duhet të jetë një numër',
		invalidCssLength: 'Vlera e fushës "%1" duhet të jetë një numër pozitiv me apo pa njësi matëse të vlefshme CSS (px, %, in, cm, mm, em, ex, pt ose pc).',
		invalidHtmlLength: 'Vlera e fushës "%1" duhet të jetë një numër pozitiv me apo pa njësi matëse të vlefshme HTML (px ose %)',
		invalidInlineStyle: 'Stili inline duhet të jetë një apo disa vlera të formatit "emër: vlerë", ndarë nga pikëpresje.',
		cssLengthTooltip: 'Fut një numër për vlerën në pixel apo një numër me një njësi të vlefshme CSS (px, %, in, cm, mm, ex, pt, ose pc).',

		// Put the voice-only part of the label in the span.
		unavailable: '%1<span class="cke_accessibility">, i padisponueshëm</span>'
	}
};
